[![Build Status](https://travis-ci.org/etalab/addok.svg?branch=master)](https://travis-ci.org/etalab/addok)

# Addok

Search engine for address. Only address.


### Dependencies

- Redis
- Python 3.4

### Documentation

http://addok.readthedocs.org/en/latest/

### Demo

http://adresse.data.gouv.fr/map/ (France database)
